==> jena-arq-2.11.0-sources.jar: org/apache/jena/riot/RDFFormatVariant.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.riot;

import org.apache.jena.atlas.lib.Lib ;

import com.hp.hpl.jena.sparql.util.Symbol ;

public class RDFFormatVariant
{
    private final Symbol symbol ;
    
    public RDFFormatVariant(String name)
    {
        symbol = Symbol.create(name) ;
    }

    @Override
    public int hashCode()
    {
        final int prime = 31 ;
        int result = 1 ;
        result = prime * result + ((symbol == null) ? 0 : symbol.hashCode()) ;
        return result ;
    }

    @Override
    public boolean equals(Object obj)
    {
        if (this == obj) return true ;
        if (obj == null) return false ;
        if (getClass() != obj.getClass()) return false ;
        RDFFormatVariant other = (RDFFormatVariant)obj ;
        if ( ! Lib.equal(symbol, other.symbol) ) return false ;
        return true ;
    }

    @Override
    public String toString()
    {
        return symbol.getSymbol() ;
    }
}

==> jena-arq-2.13.0-sources.jar: org/apache/jena/riot/RDFFormatVariant.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.riot ;

import org.apache.jena.atlas.lib.Lib ;

import com.hp.hpl.jena.sparql.util.Symbol ;

/** Modifier for an RDF Format */
public class RDFFormatVariant {
    private final Symbol symbol ;

    public RDFFormatVariant(String name) {
        symbol = Symbol.create(name) ;
    }

    @Override
    public int hashCode() {
        final int prime = 31 ;
        int result = 1 ;
        result = prime * result + ((symbol == null) ? 0 : symbol.hashCode()) ;
        return result ;
    }

    @Override
    public boolean equals(Object obj) {
        if ( this == obj )
            return true ;
        if ( obj == null )
            return false ;
        if ( getClass() != obj.getClass() )
            return false ;
        RDFFormatVariant other = (RDFFormatVariant)obj ;
        if ( !Lib.equal(symbol, other.symbol) )
            return false ;
        return true ;
    }

    @Override
    public String toString() {
        return symbol.getSymbol() ;
    }
}
